django-online
=============

.. image:: https://secure.travis-ci.org/thoas/django-online.png?branch=master
    :alt: Build Status
    :target: http://travis-ci.org/thoas/django-online

Standalone Django application to know if a django user is online or not.

Compatibility
-------------

This library is compatible with:

- python2.6, django1.4
- python2.6, django1.5
- python2.6, django1.6
- python2.7, django1.4
- python2.7, django1.5
- python2.7, django1.6
- python3.3, django1.5
- python3.3, django1.6
